@@ -1934,7 +1934,9 @@ class PatientFHIR(BaseFHIR):
 class OrganizationFHIR(BaseFHIR):
     organization_endpoint = "{base_url}/Organization"
     search_endpoint = organization_endpoint + "/_search"
-    get_by_id_endpoint = organization_endpoint + "/{id}" 
+    get_by_id_endpoint = organization_endpoint + "/{id}"
+    rrss_system = 'https://pro.consultation.rrss.rtss.qc.ca'
+    rrss_mot_cle_extension_url = 'http://www.santepublique.rtss.qc.ca/sipmi/rrss/1.0.0/extensions/#motscles'
 
     def __init__(self, base_url=None, base_uri=None, resource=None, token_header=None) -> None:
         super().__init__(base_url=base_url, base_uri=base_uri, token_header=token_header)
@@ -1946,6 +1948,20 @@ class OrganizationFHIR(BaseFHIR):
     def getFhirResource(self):
         return self.fhir_resource.as_json()
 
+    def get_id(self, organization=None):
+        if organization is None:
+            organization = self.fhir_resource
+        return organization.id
+
+    def get_id_rrss(self, organization=None):
+        if organization is None:
+            organization = self.fhir_resource
+        if organization.identifier is not None:
+            for identifier in organization.identifier:
+                if identifier.system == self.rrss_system:
+                    return identifier.value
+        return None
+
     def set_name(self, organization=None, name=None):
         if organization is None:
             organization = self.fhir_resource
@@ -1957,6 +1973,15 @@ class OrganizationFHIR(BaseFHIR):
             organization = self.fhir_resource
         return organization.name
 
+    def have_mot_cle(self, organization=None, mot_cle=None):
+        if organization is None:
+            organization = self.fhir_resource
+        if mot_cle is not None and organization.extension is not None:
+            for extension in organization.extension:
+                if extension.url == self.rrss_mot_cle_extension_url and extension.valueString == mot_cle:
+                    return True
+        return False
+
     def search(self, name=None, identifier=None):
         params = {}
         if name is not None:
@@ -1971,6 +1996,8 @@ class OrganizationFHIR(BaseFHIR):
 class LocationFHIR(BaseFHIR):
     location_endpoint = "{base_url}/Location"
     get_by_id_endpoint = location_endpoint + "/{id}"
+    rrss_system = 'https://pro.consultation.rrss.rtss.qc.ca'
+    rrss_mot_cle_extension_url = 'http://www.santepublique.rtss.qc.ca/sipmi/rrss/1.0.0/extensions/#motscles'
 
     def __init__(self, base_url=None, base_uri=None, resource=None, token_header=None) -> None:
         super().__init__(base_url=base_url, base_uri=base_uri, token_header=token_header)
@@ -1982,6 +2009,15 @@ class LocationFHIR(BaseFHIR):
     def getFhirResource(self):
         return self.fhir_resource.as_json()
 
+    def have_mot_cle(self, location=None, mot_cle=None):
+        if location is None:
+            location = self.fhir_resource
+        if mot_cle is not None and location.extension is not None:
+            for extension in location.extension:
+                if extension.url == self.rrss_mot_cle_extension_url and extension.valueString == mot_cle:
+                    return True
+        return False
+
     def set_name(self, location=None, name=None):
         if location is None:
             location = self.fhir_resource
@@ -1993,6 +2029,20 @@ class LocationFHIR(BaseFHIR):
             location = self.fhir_resource
         return location.name
 
+    def get_id(self, location=None):
+        if location is None:
+            location = self.fhir_resource
+        return location.id
+
+    def get_id_rrss(self, location=None):
+        if location is None:
+            location = self.fhir_resource
+        if location.identifier is not None:
+            for identifier in location.identifier:
+                if identifier.system == self.rrss_system:
+                    return identifier.value
+        return None
+
     def search(self, name=None, address_city=None, identifier=None):
         params = {}
         if name is not None:
